@@ -1,11 +1,13 @@
 from __future__ import annotations
 
 import asyncio
+import datetime
 import functools
 from asyncio import AbstractEventLoop
-from typing import Callable, Coroutine, Optional, TypeVar
+from typing import Callable, Coroutine, Optional, Tuple, TypeVar
 
 T = TypeVar("T")
+DEFAULT_TIME_ZONE: Optional[datetime.tzinfo] = datetime.datetime.now().astimezone().tzinfo
 
 
 def unpack_list(value: list[T], size: int) -> list[Optional[T]]:
@@ -21,6 +23,26 @@ def get_running_loop_or_create_one() -> AbstractEventLoop:
     return loop
 
 
+def parse_time_to_datetime(
+    start_time: datetime.time, end_time: datetime.time
+) -> Tuple[datetime.datetime, datetime.datetime]:
+    """Help to handle time data."""
+    start_datetime = datetime.datetime.now(DEFAULT_TIME_ZONE).replace(
+        hour=start_time.hour, minute=start_time.minute, second=0, microsecond=0
+    )
+    end_datetime = datetime.datetime.now(DEFAULT_TIME_ZONE).replace(
+        hour=end_time.hour, minute=end_time.minute, second=0, microsecond=0
+    )
+
+    if start_datetime > end_datetime:
+        end_datetime += datetime.timedelta(days=1)
+    elif end_datetime < datetime.datetime.now(DEFAULT_TIME_ZONE):
+        start_datetime += datetime.timedelta(days=1)
+        end_datetime += datetime.timedelta(days=1)
+
+    return start_datetime, end_datetime
+
+
 def run_sync():
     loop = get_running_loop_or_create_one()
 
